var config = require('./config');
var request = require('./request');

var authService = {};

/**
 * Export the config for the env
 */
authService.config = config;

/**
 * Use this method to authenticate an account.
 * @param _email The account's mail to auth.
 * @param _password the accounts's _password
 * @param onSuccess (token, account:{ id: 'xxxxxxxx-xxxxxxxx-xxxxxxxx-xxxxxxxx', mail: 'client1@test.com', created_at: null, role: 'client', verified: true })
 * @param onFail (message) is called then the auth. fails. See message for the failure details.
 * @param onError (error) is called when the execution of the auth. results in an error
 */
authService.authenticate = function (_email, _password, onSuccess, onFail, onError) {
    request.postJSON(null, config.api('/auth/verification'), {mail: _email, password: _password},
        function (body) {
            if(onSuccess != null) {
                return onSuccess(body.token, body.account);
            }
        },
        function (message) {
            return onFail(message);
        },
        function (err) {
            return onError(err);
        });
};

/**
 * // TODO: this method is mocked, impl. it!
 * Use this method to check if the given token _token is valid
 * @param _token must not be null or empty
 * @param onTrue is called when the given token _token is valid and active
 * @param onFalse is valled when the given token _token is invalid or inactive
 */
authService.isTokenActive = function (_token, onTrue, onFalse) {
    if(onTrue != null) {
        onTrue();
    }
};

module.exports = authService;

