/**
 * Services used by clients
 */
var config = require('./config');
var request = require('./request');

/**
 * Export the config for the env
 */
module.exports.config = config;

var locationService = require('./location');
var authService = require('./auth');
var userService = require('./user');
var clientService = require('./client');
var discountService = require('./discount');
var menuService = require('./menu');
var basketService = require('./basket');
var reminderService = require('./reminder');

module.exports.locationService = locationService;
module.exports.authService = authService;
module.exports.userService = userService;
module.exports.clientService = clientService;
module.exports.discountService = discountService;
module.exports.menuService = menuService;
module.exports.basketService = basketService;
module.exports.reminderService = reminderService;

/**
 * Use this method to get the currency of a given state by ISO 3166-1, alpha 2
 * @param _state must not be null
 * @param onSuccess(currency) is called on success
 * @param onFail(message) is called on failure
 * @param onError(err) is called on error or failure
 */
module.exports.getCurrencyByState = function(_state, onSuccess, onFail, onError) {
    request.getJSON(null, config.api('/public/common/currency?state=' + _state),
        function (body) {
            if(onSuccess != null) {
                return onSuccess(body.currency);
            }
        },
        function (message) {
            return onFail(message);
        },
        function (err) {
            return onError(err);
        });
};

/**
 * Use this method to get the symbole of a currency.
 *
 * Supported mapping:
 *
 * EUR == €
 * USA == $
 *
 * @param _currency must not be null, must be a valid currency
 * @returns returns the mapped currency symbol.
 */
module.exports.getCurrencySymbol = function(_currency) {
    if(_currency) {
        switch (_currency) {
            case 'EUR':
                return '€';
            case 'USD':
                return '$';
            default:
                return '';
        }
    }

    return '';
};
























