var env = process.env.NODE_ENV || 'dev';
var port = process.env.PORT || 3100;
var reminderPort = process.env.REMINDER_PORT || 3200;

var server = {};

/**
 * @returns {string} returns the current api host of the baluu-backend api-server without ending slash, like this: 'https://dev-baluu-api-server.herokuapp.com/api'
 */
server.apiURI = function () {
    switch (env) {
        case 'dev':
            return 'https://dev-baluu-api-server.herokuapp.com/api';
        case 'staging':
            return 'https://staging-baluu-api-server.herokuapp.com/api';
        case 'prod':
            return 'https://prod-baluu-api-server.herokuapp.com/api';
        case 'localhost':
            return 'http://localhost:' + port + '/api';
    }
};

/**
 * Use this method to create a uri to access api interfaces.
 * @param uri must not be null, must be a valid relative url of the baluu-backend api-server. You must place a leading "/" for a valid uri
 * @returns {string} returns a valid backend uri
 */
server.api = function (uri) {
    switch (env) {
        case 'dev':
            return 'https://dev-baluu-api-server.herokuapp.com/api' + uri;
        case 'staging':
            return 'https://staging-baluu-api-server.herokuapp.com/api' + uri;
        case 'prod':
            return 'https://prod-baluu-api-server.herokuapp.com/api' + uri;
        case 'localhost':
            return 'http://localhost:' + port + '/api' + uri;
    }
};

/**
 * Use this method to get the reminder api url.
 * @param uri must not be null, must be a valid relative url of the baluu-api-reminder. You must place a leading "/" for a valid uri
 * @returns {string} returns a valid backend uri
 */
server.apiReminder = function (uri) {
    switch (env) {
        case 'dev':
            return 'https://dev-baluu-api-reminder.herokuapp.com' + uri;
        case 'prod':
            return 'https://prod-baluu-api-reminder.herokuapp.com' + uri;
        case 'localhost':
            return 'http://localhost:' + reminderPort + uri;
    }
};

/**
 * Set the current env. to be executed for the services.
 * @param _env must be dev, staging or prod
 */
server.setEnvironment = function (_env) {
    if(_env === 'dev') {
        env = _env;
    } else if(_env === 'staging') {
        env = _env;
    } else if (_env === 'prod') {
        env = _env;
    } else if(_env === 'localhost') {
        env = _env;
    } else {
        env = 'dev';
    }
};

/**
 * Use this method to get the env of the following types:
 * - dev
 * - staging
 * - prod
 * - localhost
 *
 * @returns {*|string} returns the env
 */
server.getEnvironment = function () {
  return env;
};

module.exports = server;

