var config = require('./config');
var request = require('./request');

var preferenceService = {};

/**
 * Export the config for the env
 */
preferenceService.config = config;

/**
 * Use this query to get all allergies prefs.
 * @param onSuccess(allergies) is an array of allergies
 * @param onFail (message) called when requesting the allergies fails
 * @param onError (error) called on error or if requesting the allergies fails
 */
preferenceService.getAllergies = function (onSuccess, onFail, onError) {
    request.getJSON(null, config.api('/public/preferences/allergies'),
        function (body) {
            if(onSuccess != null) {
                return onSuccess(body.allergies);
            }
        },
        function (message) {
            return onFail(message);
        },
        function (err) {
            return onError(err);
        });
};

/**
 * Use this query to get all food prefs.
 * @param onSuccess(food) is an array of food prefs
 * @param onFail (message) called when requesting the food prefs fails
 * @param onError (error) called on error or if requesting the food prefs fails
 */
preferenceService.getFoodPreferences = function (onSuccess, onFail, onError) {
    request.getJSON(null, config.api('/public/preferences/food'),
        function (body) {
            if(onSuccess != null) {
                return onSuccess(body.food);
            }
        },
        function (message) {
            return onFail(message);
        },
        function (err) {
            return onError(err);
        });
};

/**
 * Use this query to get all beverages prefs.
 * @param onSuccess(beverages) is an array of beverages prefs
 * @param onFail (message) called when requesting the beverages prefs fails
 * @param onError (error) called on error or if requesting the beverages prefs fails
 */
preferenceService.getBeveragePreferences = function (onSuccess, onFail, onError) {
    request.getJSON(null, config.api('/public/preferences/beverages'),
        function (body) {
            if(onSuccess != null) {
                return onSuccess(body.beverages);
            }
        },
        function (message) {
            return onFail(message);
        },
        function (err) {
            return onError(err);
        });
};

/**
 * Use this query to get all cuisines prefs.
 * @param onSuccess(cuisines) is an array of cuisines prefs
 * @param onFail (message) called when requesting the cuisines prefs fails
 * @param onError (error) called on error or if requesting the cuisines prefs fails
 */
preferenceService.getCuisines = function (onSuccess, onFail, onError) {
    request.getJSON(null, config.api('/public/preferences/cuisines'),
        function (body) {
            if(onSuccess != null) {
                return onSuccess(body.cuisines);
            }
        },
        function (message) {
            return onFail(message);
        },
        function (err) {
            return onError(err);
        });
};

/**
 * Use this query to get all tastes prefs.
 * @param onSuccess(tastes) is an array of tastes prefs
 * @param onFail (message) called when requesting the tastes prefs fails
 * @param onError (error) called on error or if requesting the tastes prefs fails
 */
preferenceService.getTastes = function (onSuccess, onFail, onError) {
    request.getJSON(null, config.api('/public/preferences/tastes'),
        function (body) {
            if(onSuccess != null) {
                return onSuccess(body.tastes);
            }
        },
        function (message) {
            return onFail(message);
        },
        function (err) {
            return onError(err);
        });
};

module.exports = preferenceService;

