var request = require('superagent');

/**
 * Use this method to process and validate any response from the baluu backend-api server.
 * @param err
 * @param res must not be null
 * @param onSuccess(body) must not be null, is called when processing the response was successfully
 * @param onFail must not be null, is called when the response for the given request fails to process, due to backend failure
 * or 404 for example
 * @param onError must not be null, is called when processing the response errors, like invalid args.
 */
var processResponse = function (err, res, onSuccess, onFail, onError) {
    if(err) {
        if(onError != null) {
            if(err.response
                && err.response.body
                && err.response.body.error
                && err.response.body.success != null
                && err.response.body.success == false) {
                return onFail(err.response.body.error);
            } else {
                return onError(err);
            }
        } else {
            return;
        }
    } else {
        /**
         * Check response object
         */
        if(res != null) {
            /**
             * Check _body object
             */
            if(res.body != null) {
                /**
                 * Check success field
                 */
                if(res.body.success != null) {
                    /**
                     * Successful response
                     */
                    if(res.body.success == true && onSuccess != null) {
                        return onSuccess(res.body);
                    }
                    /**
                     * Something went wrong, request failed, success field is false
                     */
                    else if(res.body.success == false && onFail != null) {
                        if(res.body.error) {
                            return onFail(res.body.error);
                        } else {
                            return onFail(res.body);
                        }
                    }
                    else {
                        return onError(new Error('Response has no success field.'));
                    }
                } else {
                    if(onError != null) {
                        return onError(new Error('Invalid response by backend: ' + res));
                    }
                }
            }
            /**
             * Call onError for invalid _body object
             */
            else {
                if(onError != null) {
                    return onError(new Error('Invalid _body object found: ' + res));
                }
            }
        }
        /**
         * Invalid response object
         */
        else {
            if(onError != null) {
                return onError(new Error('Invalid response object found: ' + res));
            }
        }
    }
};

module.exports.postJSON = function (_token, _uri, _body, onSuccess, onFail, onError) {
    console.log('POST/ ' + _uri);
    request
        .post(_uri)
        .send(_body)
        .set('Accept', 'application/json')
        .set('token', _token)
        .end(function(err, res){
            processResponse(err, res, onSuccess, onFail, onError);
        });
};

module.exports.putJSON = function (_token, _uri, _body, onSuccess, onFail, onError) {
    console.log('PUT/ ' + _uri);
    request
        .put(_uri)
        .send(_body)
        .set('Accept', 'application/json')
        .set('token', _token)
        .end(function(err, res){
            processResponse(err, res, onSuccess, onFail, onError);
        });
};

module.exports.getJSON = function (_token, _uri, onSuccess, onFail, onError) {
    console.log('GET/ ' + _uri);
    request
        .get(_uri)
        .set('Accept', 'application/json')
        .set('token', _token)
        .end(function(err, res){
            processResponse(err, res, onSuccess, onFail, onError);
        });
};

module.exports.deleteJSON = function (_token, _uri, onSuccess, onFail, onError) {
    console.log('DELETE/ ' + _uri);
    request
        .delete(_uri)
        .set('Accept', 'application/json')
        .set('token', _token)
        .end(function(err, res){
            processResponse(err, res, onSuccess, onFail, onError);
        });
};

module.exports.request = request;