var assert = require('assert');
var chai = require('chai');
var expect = chai.expect; // we are using the "expect" style of Chai

var testService = require('./test');
var authService = require('./../auth');

describe('Authentication', function() {
    before(function(done) {
        /**
         * Migrate the test data
         */
        testService.config.setEnvironment('localhost');
        testService.migrate(function (message) {
            console.log(message);
            setup(done);
        }, function (message) {
            console.error(message);
            return done(new Error(message));
        }, function (err) {
            console.error(err);
            return done(err);
        });
    });

    after(function(done) {
        /**
         * Drop the test data
         */
        testService.truncate(function (message) {
            console.log(message);
            done();
        }, function (message) {
            console.error(message);
            done(new Error(message));
        }, function (err) {
            console.error(err);
            done(err);
        });
    });

    /**
     * Init. the testing environment
     */
    function setup(done) {
        /**
         * set the api enviroment to localhost for the CI setup
         */
        authService.config.setEnvironment('localhost');

        done();
    }

    /**
     * Test the authService
     */
    describe('AuthService', function() {
        describe('#authenticate(mail, pw, onSuccess, onFail, onError)', function() {
            it('should successfully authenticate client', function (done) {
                var client = 'client@test.com';
                authService.authenticate(client, '123', function (token, account) {
                    assert.equal(client, account.mail);
                    assert.equal('client', account.role);
                    done();
                }, function (message) {
                    done(new Error(message));
                }, function (err) {
                    done(err);
                });
            });
        });

        describe('#authenticate(mail, pw, onSuccess, onFail, onError)', function() {
            it('should successfully authenticate user', function (done) {
                var user = 'user@test.com';
                authService.authenticate(user, '123', function (token, account) {
                    assert.equal(user, account.mail);
                    assert.equal('user', account.role);
                    done();
                }, function (message) {
                    done(new Error(message));
                }, function (err) {
                    done(err);
                });
            });
        });

        describe('#authenticate(mail, pw, onSuccess, onFail, onError)', function() {
            it('should fail the authentication', function (done) {
                authService.authenticate('', '', function (token, account) {
                    assert.equal(client, account.mail);
                    assert.equal('client', account.role);
                    done(new Error('This should never be called'));
                }, function (message) {
                    done();
                }, function (err) {
                    done(err);
                });
            });
        });

        describe('#authenticate(mail, pw, onSuccess, onFail, onError)', function() {
            it('should fail the authentication', function (done) {
                authService.authenticate('asdf', 'adfasdf', function (token, account) {
                    assert.equal(client, account.mail);
                    assert.equal('client', account.role);
                    done(new Error('This should never be called'));
                }, function (message) {
                    done();
                }, function (err) {
                    done(err);
                });
            });
        });
    });
});