var assert = require('assert');
var chai = require('chai');
var expect = chai.expect; // we are using the "expect" style of Chai

var testService = require('./test');
var authService = require('./../auth');
var clientService = require('./../client');

var client = 'client@test.com'
var password = '123';
var token = '';

var account = null;

describe('Client', function () {
    before(function(done) {
        /**
         * Migrate the test data
         */
        testService.config.setEnvironment('localhost');
        testService.migrate(function (message) {
            console.log(message);
            setup(done);
        }, function (message) {
            console.error(message);
            return done(new Error(message));
        }, function (err) {
            console.error(err);
            return done(err);
        });
    });

    after(function(done) {
        /**
         * Drop the test data
         */
        testService.truncate(function (message) {
            console.log(message);
            done();
        }, function (message) {
            console.error(message);
            done(new Error(message));
        }, function (err) {
            console.error(err);
            done(err);
        });
    });

    /**
     * Init. the testing environment
     */
    function setup(done) {
        /**
         * set the api environment to localhost for the CI setup
         */
        authService.config.setEnvironment('localhost');
        clientService.config.setEnvironment('localhost');

        /**
         * auth. this test/account
         */
        authService.authenticate(client, password, function (_token, _account) {
            token = _token;
            account = _account;

            done();
        }, function (message) {
            console.error('Account auth. failed, test suit aborted.')
            done(new Error(message));
        }, function (err) {
            console.error('Account auth. failed, test suit aborted.')
            done(err);
        });
    }

    /**
     * Test the ClientService
     */
    describe('ClientService', function () {
        describe('#setClient(_token, _first_name, _last_name, _title, onSuccess, onFail, onError)', function () {

            it('should successfully update the clients firstname, lastname and title', function (done) {
                clientService.setClient(token, 'Max', 'Muster', 'Office Manager', function () {
                    clientService.getClient(token, function (client, account) {
                        assert.equal(client.first_name, 'Max');
                        assert.equal(client.last_name, 'Muster');
                        assert.equal(client.title, 'Office Manager');
                        done();
                    }, function (message) {
                        done(new Error(message));
                    }, function (err) {
                        done(err);
                    });
                }, function (message) {
                    done(new Error(message));
                }, function (err) {
                    done(err);
                });
            });
        });
    });

});