var assert = require('assert');
var chai = require('chai');
var expect = chai.expect; // we are using the "expect" style of Chai

var commonService = require('./../common');

describe('Common Logic', function () {
    // within before() you can run all the operations that are needed to setup your tests. In this case
    before(function (done) {
        /**
         * set the api environment to localhost for the CI setup
         */
        commonService.config.setEnvironment('localhost');

        done();
    });

    /**
     * Test the authService
     */
    describe('CommonService', function () {
        describe('#getCurrencyByState(_state, onSuccess, onFail, onError)', function () {
            it('should successfully get the EUR currency', function (done) {
                commonService.getCurrencyByState('AT',
                    function (currency) {
                        assert.equal('EUR', currency);
                        done();
                    }, function (message) {
                        done(new Error(message));
                    }, function (err) {
                        done(err);
                    });
            });
        });

        describe('#getCurrencyByState(_state, onSuccess, onFail, onError)', function () {
            it('should fail due to invalid state', function (done) {
                commonService.getCurrencyByState('SomeWrongState',
                    function (currency) {
                        done(new Error('The success method should never be called.'));
                    }, function (message) {
                        done();
                    }, function (err) {
                        done(err);
                    });
            });
        });
    });
});