var assert = require('assert');
var chai = require('chai');
var expect = chai.expect; // we are using the "expect" style of Chai

var testService = require('./test');
var prefService = require('./../preference');

describe('Preferences & Allergies', function () {
    before(function(done) {
        /**
         * Migrate the test data
         */
        testService.config.setEnvironment('localhost');
        testService.migrate(function (message) {
            console.log(message);
            setup(done);
        }, function (message) {
            console.error(message);
            return done(new Error(message));
        }, function (err) {
            console.error(err);
            return done(err);
        });
    });

    after(function(done) {
        /**
         * Drop the test data
         */
        testService.truncate(function (message) {
            console.log(message);
            done();
        }, function (message) {
            console.error(message);
            done(new Error(message));
        }, function (err) {
            console.error(err);
            done(err);
        });
    });

    /**
     * Init. the testing environment
     */
    function setup(done) {
        /**
         * set the api environment to localhost for the CI setup
         */
        prefService.config.setEnvironment('localhost');

        done();
    }

    /**
     * Test the MenuService
     */
    describe('PreferenceService', function () {
        describe('#getAllergies(onSuccess, onFail, onError)', function () {
            it('should get all allergies', function (done) {
                prefService.getAllergies(function (allergies) {
                    assert.ok(Array.isArray(allergies) && allergies.length);
                    done();
                }, function (message) {
                    done(new Error(message))
                }, function (err) {
                    done(err);
                });
            });
        });

        describe('#getTastes(onSuccess, onFail, onError)', function () {
            it('should get all tastes', function (done) {
                prefService.getTastes(function (tastes) {
                    assert.ok(Array.isArray(tastes) && tastes.length);
                    done();
                }, function (message) {
                    done(new Error(message))
                }, function (err) {
                    done(err);
                });
            });
        });

        describe('#getFoodPreferences(onSuccess, onFail, onError)', function () {
            it('should get all food prefs', function (done) {
                prefService.getFoodPreferences(function (food) {
                    assert.ok(Array.isArray(food) && food.length);
                    done();
                }, function (message) {
                    done(new Error(message))
                }, function (err) {
                    done(err);
                });
            });
        });

        describe('#getBeveragePreferences(onSuccess, onFail, onError)', function () {
            it('should get all beverages prefs', function (done) {
                prefService.getBeveragePreferences(function (beverages) {
                    assert.ok(Array.isArray(beverages) && beverages.length);
                    done();
                }, function (message) {
                    done(new Error(message))
                }, function (err) {
                    done(err);
                });
            });
        });

        describe('#getCuisines(onSuccess, onFail, onError)', function () {
            it('should get all cuisines prefs', function (done) {
                prefService.getCuisines(function (cuisines) {
                    assert.ok(Array.isArray(cuisines) && cuisines.length);
                    done();
                }, function (message) {
                    done(new Error(message))
                }, function (err) {
                    done(err);
                });
            });
        });
    });
});