var config = require('./../config');
var request = require('./../request');

var testService = {};

/**
 * Export the config for the env
 */
testService.config = config;

/**
 * Use this method to migrate the api-server test data. The migration will only be possible, if the server
 * was started for testing purposes.
 *
 * @param onSuccess(message) called when migration was successful
 * @param onFail(message) called when migration fails
 * @param onError called on error or if migration fails
 */
testService.migrate = function (onSuccess, onFail, onError) {
    request.putJSON(null, config.api('/public/tests/migration/run'),
        {},
        function (body) {
            if(onSuccess != null) {
                return onSuccess(body.message);
            }
        },
        function (message) {
            return onFail(message);
        },
        function (err) {
            return onError(err);
        });
};

/**
 * Use this method to truncate the migration test data. The server must be in testing mode started.
 *
 * @param onSuccess(message) called when truncate was successful
 * @param onFail(message) called when truncate failed
 * @param onError called on error or if truncate failed
 */
testService.truncate = function (onSuccess, onFail, onError) {
    request.deleteJSON(null, config.api('/public/tests/migration/truncate'),
        function (body) {
            if(onSuccess != null) {
                return onSuccess(body.message);
            }
        },
        function (message) {
            return onFail(message);
        },
        function (err) {
            return onError(err);
        });
};

module.exports = testService;

